@@ -95,7 +95,7 @@ struct app_conn_t {
   /* Radius authentication stuff */
   /* Parameters are initialised whenever a reply to an access request
      is received. */
-  uint8_t chal[EAP_LEN];         /* EAP challenge */
+  uint8_t chal[MAX_EAP_LEN];     /* EAP challenge */
   size_t challen;                /* Length of EAP challenge */
   uint8_t sendkey[RADIUS_ATTR_VLEN];
   uint8_t recvkey[RADIUS_ATTR_VLEN];
@@ -165,6 +165,7 @@ int chilli_req_attrs(struct radius_t *radius,
 
 int chilli_auth_radius(struct radius_t *radius);
 
+int chilli_signal(int signo, void (*func)(int));
 void chilli_signals(int *with_term, int *with_hup);
 
 int chilli_binconfig(char *file, size_t flen, pid_t pid);
@@ -219,4 +220,18 @@ void GenerateAuthenticatorResponse(u_char *Password, int PasswordLen,
 				   int UserNameLen, u_char *AuthenticatorResponse);
 #endif
 
+int chilli_handle_signal(void *ctx, int fd);
+
+/* utils.c */
+int statedir_file(char *dst, int dlen, char *file, char *deffile);
+
+/* sig.c */
+int ndelay_on (int fd);
+int ndelay_off (int fd);
+int set_signal (int signo, void (*func)(int));
+int selfpipe_init (void);
+int selfpipe_read (void);
+int selfpipe_trap (int signo);
+void selfpipe_finish();
+
 #endif /*_CHILLI_H */
