@@ -1,6 +1,6 @@
 /* 
  * Copyright (C) 2003, 2004, 2005 Mondru AB.
- * Copyright (C) 2007-2009 Coova Technologies, LLC. <support@coova.com>
+ * Copyright (C) 2007-2010 Coova Technologies, LLC. <support@coova.com>
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -133,6 +133,8 @@ struct dhcp_conn_t {
   struct dhcp_nat_t dnat[DHCP_DNAT_MAX]; /* Destination NAT */
   uint16_t mtu;                /* Maximum transfer unit */
 
+  struct in_addr migrateip;    /* Client IP address to migrate to */
+  time_t last_nak;
 
 #ifdef ENABLE_IEEE8021Q
   uint16_t tag8021q;
@@ -160,6 +162,10 @@ struct dhcp_t {
 
   /* network interfaces */
   struct _net_interface rawif; 
+#ifdef HAVE_NETFILTER_QUEUE
+  struct _net_interface qif_in; 
+  struct _net_interface qif_out; 
+#endif
 
   int numconn;          /* Maximum number of connections */
 #if defined(__FreeBSD__) || defined (__APPLE__) || defined (__OpenBSD__)
@@ -198,7 +204,7 @@ struct dhcp_t {
   struct dhcp_conn_t **hash;    /* Hashsize array of pointer to member */
 
   pass_through pass_throughs[MAX_PASS_THROUGHS];
-  size_t num_pass_throughs;
+  uint32_t num_pass_throughs;
 
   /* Call back functions */
   int (*cb_data_ind) (struct dhcp_conn_t *conn, uint8_t *pack, size_t len);
@@ -216,7 +222,7 @@ int dhcp_new(struct dhcp_t **dhcp, int numconn, char *interface,
 	 int usemac, uint8_t *mac, int promisc, 
 	 struct in_addr *listen, int lease, int allowdyn,
 	 struct in_addr *uamlisten, uint16_t uamport, 
-	 int useeapol, int noc2c);
+	 int noc2c);
 
 int dhcp_set(struct dhcp_t *dhcp, char *ethers, int debug);
 
@@ -224,6 +230,9 @@ int dhcp_free(struct dhcp_t *dhcp);
 
 int dhcp_timeout(struct dhcp_t *this);
 
+int dhcp_send(struct dhcp_t *this, struct _net_interface *netif, 
+	      unsigned char *hismac, uint8_t *packet, size_t length);
+
 struct timeval * dhcp_timeleft(struct dhcp_t *this, struct timeval *tvp);
 
 int dhcp_validate(struct dhcp_t *this);
