@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2007-2009 Coova Technologies, LLC. <support@coova.com>
+ * Copyright (C) 2007-2010 Coova Technologies, LLC. <support@coova.com>
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,11 +16,7 @@
  * 
  */
 
-#include "dns.h"
-#include "garden.h"
-#include "syserr.h"
-#include "dhcp.h"
-#include "options.h"
+#include "chilli.h"
 
 #define antidnstunnel _options.dnsparanoia
 
