@@ -1,6 +1,6 @@
 /* 
  * Copyright (C) 2003, 2004, 2005 Mondru AB.
- * Copyright (C) 2007-2009 Coova Technologies, LLC. <support@coova.com>
+ * Copyright (C) 2007-2010 Coova Technologies, LLC. <support@coova.com>
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,21 +17,11 @@
  * 
  */
 
-#include "system.h"
-#include "ippool.h"
-#include "radius.h"
-#include "radius_wispr.h"
-#include "radius_chillispot.h"
-#include "redir.h"
-#include "syserr.h"
-#include "dhcp.h"
-#include "cmdline.h"
 #include "chilli.h"
-#include "options.h"
 
-int pass_through_add(pass_through *ptlist, size_t ptlen,
-		     size_t *ptcnt, pass_through *pt) {
-  size_t cnt = *ptcnt;
+int pass_through_add(pass_through *ptlist, uint32_t ptlen,
+		     uint32_t *ptcnt, pass_through *pt) {
+  uint32_t cnt = *ptcnt;
   int i;
 
   if (cnt >= ptlen) {
@@ -58,8 +48,8 @@ int pass_through_add(pass_through *ptlist, size_t ptlen,
   return 0;
 }
 
-int pass_throughs_from_string(pass_through *ptlist, size_t ptlen, 
-			      size_t *ptcnt, char *s) {
+int pass_throughs_from_string(pass_through *ptlist, uint32_t ptlen, 
+			      uint32_t *ptcnt, char *s) {
   struct hostent *host;
   pass_through pt;
   char *t, *p1 = NULL, *p2 = NULL;
@@ -150,9 +140,9 @@ int pass_throughs_from_string(pass_through *ptlist, size_t ptlen,
 }
 
 #ifdef ENABLE_CHILLIREDIR
-int regex_pass_throughs_from_string(regex_pass_through *ptlist, size_t ptlen, 
-				    size_t *ptcnt, char *s) {
-  size_t cnt = *ptcnt;
+int regex_pass_throughs_from_string(regex_pass_through *ptlist, uint32_t ptlen, 
+				    uint32_t *ptcnt, char *s) {
+  uint32_t cnt = *ptcnt;
   regex_pass_through pt;
   char *p, *st;
   int stage = 0;
