@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2007-2009 Coova Technologies, LLC. <support@coova.com>
+ * Copyright (C) 2007-2010 Coova Technologies, LLC. <support@coova.com>
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -46,10 +46,10 @@ typedef struct regex_pass_through_t {
   char reserved:5;
 } regex_pass_through;
 
-int regex_pass_throughs_from_string(regex_pass_through *ptlist, size_t ptlen, size_t *ptcnt, char *s);
+int regex_pass_throughs_from_string(regex_pass_through *ptlist, uint32_t ptlen, uint32_t *ptcnt, char *s);
 #endif
 
-int pass_through_add(pass_through *ptlist, size_t ptlen, size_t *ptcnt, pass_through *pt);
-int pass_throughs_from_string(pass_through *ptlist, size_t ptlen, size_t *ptcnt, char *s);
+int pass_through_add(pass_through *ptlist, uint32_t ptlen, uint32_t *ptcnt, pass_through *pt);
+int pass_throughs_from_string(pass_through *ptlist, uint32_t ptlen, uint32_t *ptcnt, char *s);
 
 #endif
