@@ -70,6 +70,7 @@ typedef struct _proxy_request {
 } proxy_request;
 
 static int max_requests = 0;
+static int num_requests_free = 0;
 static proxy_request * requests = 0;
 static proxy_request * requests_free = 0;
 
@@ -83,7 +84,7 @@ static proxy_request * get_request() {
   int i;
 
   if (!max_requests) {
-
+    /* Initialize linked list */
     max_requests = 16; /* hard maximum! (should be configurable) */
 
     requests = (proxy_request *) calloc(max_requests, sizeof(proxy_request));
@@ -96,6 +97,7 @@ static proxy_request * get_request() {
     }
     
     requests_free = requests;
+    num_requests_free = max_requests;
   }
   
   if (requests_free) {
@@ -103,13 +105,16 @@ static proxy_request * get_request() {
     requests_free = requests_free->next;
     if (requests_free)
       requests_free->prev = 0;
+    num_requests_free--;
   }
   
   if (!req) {
     /* problem */
-    log_err(0,"out of connections\n");
+    log_err(0,"out of connections");
     return 0;
   }
+
+  log_dbg("connections free %d", num_requests_free);
   
   req->next = req->prev = 0;
   req->inuse = 1;
@@ -142,6 +147,8 @@ static void close_request(proxy_request *req) {
     req->data = 
     req->post = 
     req->wbuf = 0;
+  
+  req->authorized = 0;
 
   req->inuse = 0;
   if (requests_free) {
@@ -149,6 +156,9 @@ static void close_request(proxy_request *req) {
     req->next = requests_free;
   }
   requests_free = req;
+  num_requests_free++;
+
+  log_dbg("connections free %d", num_requests_free);
 }
 
 static int http_aaa_finish(proxy_request *req) {
@@ -177,10 +187,10 @@ static int http_aaa_finish(proxy_request *req) {
     
   case RADIUS_CODE_ACCESS_REQUEST:
     log_dbg("Access-%s", req->authorized ? "Accept" : "Reject");
-    if (req->authorized) {
-      radius_default_pack(radius, &req->radius_res, RADIUS_CODE_ACCESS_ACCEPT);
-      break;
-    }
+    radius_default_pack(radius, &req->radius_res, 
+			req->authorized ? RADIUS_CODE_ACCESS_ACCEPT :
+			RADIUS_CODE_ACCESS_REJECT);
+    break;
 
   default:
     radius_default_pack(radius, &req->radius_res, RADIUS_CODE_ACCESS_REJECT);
@@ -423,7 +433,7 @@ static int http_conn_finish(struct conn_t *conn, void *ctx) {
 static int http_conn_read(struct conn_t *conn, void *ctx) {
   proxy_request *req = (proxy_request *)ctx;
   char c[1];
-  int r = read(conn->sock, c, 1);
+  int r = safe_read(conn->sock, c, 1);
   if (r == 1) {
     switch (c[0]) {
     case '\r': break;
@@ -589,7 +599,7 @@ static void http_aaa_register(int argc, char **argv, int i) {
   }
 
   if (req.data->slen)
-    if (write(1, req.data->data, req.data->slen) < 0)
+    if (safe_write(1, req.data->data, req.data->slen) < 0)
       log_err(errno, "write()");
 
   bdestroy(req.url);
@@ -920,8 +930,12 @@ int main(int argc, char **argv) {
   int keep_going = 1;
   int reload_config = 1;
 
+  int selfpipe;
+
   options_init();
 
+  selfpipe = selfpipe_init();
+
   chilli_signals(&keep_going, &reload_config);
 
   /*
@@ -981,6 +995,7 @@ int main(int argc, char **argv) {
     FD_ZERO(&fdwrite);
     FD_ZERO(&fdexcep);
 
+    FD_SET(selfpipe, &fdread);
     FD_SET(radius_auth->fd, &fdread);
     FD_SET(radius_acct->fd, &fdread);
 
@@ -1017,6 +1032,10 @@ int main(int argc, char **argv) {
 	struct sockaddr_in addr;
 	socklen_t fromlen = sizeof(addr);
 	
+	if (FD_ISSET(selfpipe, &fdread)) {
+	  chilli_handle_signal(0, 0);
+	}
+
 	if (FD_ISSET(radius_auth->fd, &fdread)) {
 	  /*
 	   *    ---> Authentication
@@ -1086,5 +1105,7 @@ int main(int argc, char **argv) {
   curl_global_cleanup();
 #endif
 
+  selfpipe_finish();
+
   return 0;
 }
