@@ -78,7 +78,8 @@ int static chilliauth() {
 
   if (!_options.adminuser || !_options.adminpasswd) return 1;
 
-  if (radius_new(&radius, &_options.radiuslisten, 0, 0, NULL, 0, NULL, NULL, NULL)) {
+  if (radius_new(&radius, &_options.radiuslisten, 0, 0, NULL, 0, NULL, NULL, NULL) ||
+      radius_init_q(radius, 4)) {
     log_err(0, "Failed to create radius");
     return ret;
   }
