@@ -1,7 +1,7 @@
 /* 
  * Copyright (C) 2003, 2004, 2005 Mondru AB.
  * Copyright (C) 2006 PicoPoint B.V.
- * Copyright (C) 2007-2009 Coova Technologies, LLC. <support@coova.com>
+ * Copyright (C) 2007-2010 Coova Technologies, LLC. <support@coova.com>
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,8 +20,7 @@
 
 #define MAIN_FILE
 
-#include "system.h"
-#include "options.h"
+#include "chilli.h"
 
 struct options_t _options;
 
@@ -67,8 +66,6 @@ enum {
 #elif defined(__ia64__)
 #define __NR_ioprio_set         1274
 #define __NR_ioprio_get         1275
-#else
-#warning "ioprio not supported"
 #endif
 #endif
 #endif
