@@ -32,6 +32,13 @@ static void destroy_one_ring(net_interface *iface, int what);
 static void setup_filter(net_interface *iface);
 #endif
 
+int safe_accept(int fd, struct sockaddr *sa, socklen_t *lenptr) {
+  int ret;
+  do {
+    ret = accept(fd, sa, lenptr);
+  } while (ret == -1 && errno == EINTR);
+  return ret;
+}
 
 int safe_connect(int s, struct sockaddr *sock, size_t len) {
   int ret;
@@ -57,6 +64,14 @@ int safe_write(int s, void *b, size_t blen) {
   return ret;
 }
 
+int safe_close (int fd) {
+  int ret;
+  do {
+    ret = close(fd);
+  } while (ret == -1 && errno == EINTR);
+  return ret;
+}
+
 int dev_set_flags(char const *dev, int flags) {
   struct ifreq ifr;
   int fd;
@@ -573,7 +588,7 @@ net_read(net_interface *netif, void *d, size_t dlen) {
     /*len = recvfrom(netif->fd, d, netif->mtu,
       MSG_DONTWAIT | MSG_TRUNC, NULL, NULL);*/
 
-    len = read(netif->fd, d, dlen);
+    len = safe_read(netif->fd, d, dlen);
 
     if (len < 0) {
 #ifdef ENETDOWN
@@ -605,7 +620,7 @@ ssize_t net_write2(net_interface *netif, void *d, size_t dlen, struct sockaddr_l
   if (dest) {
     len = sendto(fd, d, dlen, 0, (struct sockaddr *)dest, sizeof(struct sockaddr_ll));
   } else {
-    len = write(fd, d, dlen);
+    len = safe_write(fd, d, dlen);
   }
 
   if (len < 0) {
@@ -734,7 +749,7 @@ int net_route(struct in_addr *dst, struct in_addr *gateway,
   req.mask.sin_addr.s_addr = mask->s_addr;
   req.gate.sin_addr.s_addr = gateway->s_addr;
   
-  if (write(fd, rtm, rtm->rtm_msglen) < 0) {
+  if (safe_write(fd, rtm, rtm->rtm_msglen) < 0) {
     log_err(errno, "write() failed");
     close(fd);
     return -1;
