@@ -19,7 +19,7 @@
 
 #include "chilli.h"
 
-#define _debug_ 0
+#define deeplog 0
 
 void radius_addnasip(struct radius_t *radius, struct radius_packet_t *pack)  {
   struct in_addr inaddr;
@@ -52,7 +52,7 @@ void radius_addcalledstation(struct radius_t *radius, struct radius_packet_t *pa
   radius_addattr(radius, pack, RADIUS_ATTR_CALLED_STATION_ID, 0, 0, 0, mac, strlen((char*)mac)); 
 }
 
-#if(_debug_)
+#if(deeplog)
 int radius_printqueue(struct radius_t *this) {
   int mx = 256;
   int n;
@@ -202,7 +202,7 @@ int radius_queue_in(struct radius_t *this, struct radius_packet_t *pack,
   int qnext = this->qnext;
   int attempt = 0;
 
-#if(_debug_)
+#if(deeplog)
   if (_options.debug) {
     radius_printqueue(this);
   }
@@ -277,8 +277,11 @@ int radius_queue_in(struct radius_t *this, struct radius_packet_t *pack,
     this->qnext %= this->qsize;
   }
   
-#if(_debug_)
+#if(deeplog)
   if (_options.debug) {
+    log_dbg("sending radius packet (code=%d, id=%d, len=%d)\n",
+	    pack->code, pack->id, ntohs(pack->length));
+
     radius_printqueue(this);
   }
 #endif
@@ -329,7 +332,7 @@ radius_queue_out(struct radius_t *this, struct radius_packet_t *pack,
     return -1;
   }
 
-#if(_debug_)
+#if(deeplog)
   if (_options.debug) {
     log_dbg("radius_queue_out");
     radius_printqueue(this);
@@ -352,7 +355,7 @@ radius_queue_out(struct radius_t *this, struct radius_packet_t *pack,
   else
     this->queue[this->queue[idx].prev].next = this->queue[idx].next;
 
-#if(_debug_)
+#if(deeplog)
   if (_options.debug) {
     log_dbg("radius_queue_out end");
     radius_printqueue(this);
@@ -374,7 +377,7 @@ static int radius_queue_reschedule(struct radius_t *this, int idx) {
     return -1;
   }
 
-#if(_debug_)
+#if(deeplog)
   if (_options.debug) {
     log_dbg("radius_reschedule");
     radius_printqueue(this);
@@ -413,7 +416,7 @@ static int radius_queue_reschedule(struct radius_t *this, int idx) {
     this->first = idx;  /* First and last */
   }
   
-#if(_debug_)
+#if(deeplog)
   if (_options.debug) {
     radius_printqueue(this);
   }
@@ -561,7 +564,7 @@ int radius_timeout(struct radius_t *this) {
 
   gettimeofday(&now, NULL);
 
-#if(_debug_)
+#if(deeplog)
   if (_options.debug) {
     log_dbg("radius_timeout(%d) %8d %8d", this->first, 
 	    (int)now.tv_sec, (int)now.tv_usec);
@@ -634,7 +637,7 @@ int radius_timeout(struct radius_t *this) {
     }    
   }
   
-#if(_debug_)
+#if(deeplog)
   if (_options.debug) {
     log_dbg("radius_timeout");
     if (this->first > 0) {
@@ -884,6 +887,15 @@ radius_cmpattr(struct radius_attr_t *t1, struct radius_attr_t *t2) {
 /*
  * radius_keydecode()
  * Decode an MPPE key using MD5.
+    0                   1                   2                   3
+    0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
+   +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+   |  Vendor-Type  | Vendor-Length |             Salt
+   +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+                               String...
+   +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+
+   *src points to the first byte of "Salt".
  */
 int radius_keydecode(struct radius_t *this, 
 		     uint8_t *dst, size_t dstsize, size_t *dstlen, 
@@ -895,6 +907,11 @@ int radius_keydecode(struct radius_t *this,
   int blocks;
   int i, n;
 
+  if (srclen < 18) {
+    log_err(0, "radius_keydecode MPPE attribute content len must be at least 18, len = %d", srclen);
+    return -1;
+  }
+ 
   blocks = ((int)srclen - 2) / RADIUS_MD5LEN;
 
   if ((blocks * RADIUS_MD5LEN + 2) != (int)srclen) {
@@ -902,11 +919,6 @@ int radius_keydecode(struct radius_t *this,
     return -1;
   }
 
-  if (blocks < 1) {
-    log_err(0, "radius_keydecode srclen must be at least 18");
-    return -1;
-  }
-
   /* Get MD5 hash on secret + authenticator (First 16 octets) */
   MD5Init(&context);
   MD5Update(&context, (uint8_t *)secret, secretlen);
@@ -914,20 +926,20 @@ int radius_keydecode(struct radius_t *this,
   MD5Update(&context, src, 2);
   MD5Final(b, &context);
 
-  if ((src[2] ^ b[0]) > dstsize) {
-    log_err(0,"radius_keydecode dstsize too small (%d > %d)",
-	    (src[2] ^ b[0]), dstlen);
-    return -1; 
-  }
-
-  if ((src[2] ^ b[0]) > (srclen - 2)) {
-    log_err(0,"radius_keydecode dstlen (%d) > srclen - 2 (%d)", 
-	    (src[2] ^ b[0]), (srclen - 2));
-    return -1; 
-  }
-
+  /* First byte of the plainstring is the length of the key */
   *dstlen = (size_t)(src[2] ^ b[0]);
+  
+  if (*dstlen > (srclen - 3)) {
+    log_err(0,"radius_keydecode not enough encrypted data bytes for indicated key length = %d (bytes)", *dstlen);
+    return -1; 
+  }
 
+  if (*dstlen > dstsize) {
+    log_err(0,"radius_keydecode output buffer for plaintext key is too small");
+    return -1; 
+  }
+
+  /* Note: first byte is used for len, only 15 bytes of key */
   for (i = 1; i < RADIUS_MD5LEN; i++) {
     if ((i-1) < (int)*dstlen) {
       dst[i-1] = src[i+2] ^ b[i];
