@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2007-2009 Coova Technologies, LLC. <support@coova.com>
+ * Copyright (C) 2007-2010 Coova Technologies, LLC. <support@coova.com>
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,6 +38,10 @@
 #include <stdlib.h>
 #endif
 
+#ifdef HAVE_STDDEF_H
+#include <stddef.h>
+#endif
+
 #ifdef HAVE_SYSLOG_H
 #include <syslog.h>
 #endif
@@ -194,6 +198,18 @@
 #include <endian.h>
 #endif
 
+#ifdef HAVE_LIBGEN_H
+#include <libgen.h>
+#endif
+
+#ifdef HAVE_PWD_H
+#include <pwd.h>
+#endif
+
+#ifdef HAVE_GRP_H
+#include <grp.h>
+#endif
+
 #undef LITTLE_ENDIAN
 #undef BIG_ENDIAN
 
@@ -228,8 +244,6 @@
     })
 #endif
 
-#define offsetof(TYPE, MEMBER) ((int)&((TYPE *)0)->MEMBER)
-
 #define SET_SA_FAMILY(addr, family)			\
     memset ((char *) &(addr), '\0', sizeof(addr));	\
     addr.sa_family = (family);
